﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;


namespace RadarChart
{
	public partial class MainForm : Form
	{
		double alpha = 0;

		public MainForm()
		{
			InitializeComponent();			

			// create sample data
			radarChart.Series = new ObservableCollection<Series>
			{ 
				new SimpleSeries(
					new List<double>()
					{
						20, 30, 43, 40, 44, 37, 35, 51
					},
					new List<string>()
					{
						"20", "30", "43", "40", "44", "37", "35", "51"
					}
				),
				new SimpleSeries(
					new List<double>()
					{
						12, 40, 23, 30, 34, 47, 45, 21
					},
					new List<string>()
					{
						"12", "40", "23", "30", "34", "47", "45", "21"
					}
				)
			};

			// define axis appearance
			radarChart.Theme.AxisLabelsBrush = new MindFusion.Drawing.SolidBrush(Color.Black);
			radarChart.Theme.AxisLabelsFontStyle = FontStyle.Bold;
			radarChart.Theme.AxisLabelsFontSize = 10;
			radarChart.Theme.AxisStroke = new MindFusion.Drawing.SolidBrush(Color.LightGray);
            radarChart.Theme.DataLabelsBackground = new MindFusion.Drawing.SolidBrush(Color.White);
            radarChart.Theme.DataLabelsBorderStroke = new MindFusion.Drawing.SolidBrush(Color.Gray);

			radarChart.GridDivisions = 5;
			radarChart.DefaultAxis.MinValue = 0;
			radarChart.DefaultAxis.MaxValue = 55;
			radarChart.ShowLegend = false;
			
			for(int i = 0; i< 8; i++)
				radarChart.Axes.Add(new Axis()
				{
					Title = string.Format("Axis {0}", i+1)
				});

			// fill enumeration combo boxes
			cbxGridType.Items.Add(RadarGridType.Radar);
			cbxGridType.Items.Add(RadarGridType.Spiderweb);
			cbxGridType.SelectedIndex = 1;

			cbxRadarType.Items.Add(RadarType.Pie);
			cbxRadarType.Items.Add(RadarType.Polygon);
			cbxRadarType.SelectedIndex = 1;

			radarChart.GridType = RadarGridType.Spiderweb;
			radarChart.RadarType = RadarType.Polygon;
			radarChart.GridColor1 = Color.White;
			radarChart.GridColor2 = Color.FromArgb(245, 245, 245);

			// specify one color per series
			radarChart.Plot.SeriesStyle = new PerSeriesStyle()
			{
				Strokes = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
				},
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
				},
				StrokeThicknesses = new List<double>
				{
					5.0
				}
			};
		}

		private void tbRadius_Scroll(object sender, EventArgs e)
		{
			radarChart.ChartPadding = tbRadius.Value;
			radarChart.Invalidate();
		}

		private void chbAllowRotate_CheckedChanged(object sender, EventArgs e)
		{
			radarChart.AllowRotate = !radarChart.AllowRotate;
		}

		private void tbStartAngle_Scroll(object sender, EventArgs e)
		{
			radarChart.StartAngle = tbStartAngle.Value;
			radarChart.Invalidate();
		}

		private void chbShowDataLabels_CheckedChanged(object sender, EventArgs e)
		{
			if (chbShowDataLabels.Checked)
				radarChart.ShowDataLabels = LabelKinds.All;
			else
				radarChart.ShowDataLabels = LabelKinds.None;
			radarChart.Invalidate();
		}

		private void tbGridDivisions_Scroll(object sender, EventArgs e)
		{
			radarChart.GridDivisions = tbGridDivisions.Value;
			radarChart.Invalidate();
		}

		private void tbAxisMinValue_Scroll(object sender, EventArgs e)
		{
			radarChart.DefaultAxis.MinValue = tbAxisMinValue.Value;
			radarChart.Invalidate();
		}

		private void tbAxisMaxValue_Scroll(object sender, EventArgs e)
		{
			radarChart.DefaultAxis.MaxValue = tbAxisMaxValue.Value;
			radarChart.Invalidate();	
		}

		private void cbxGridType_SelectedValueChanged(object sender, EventArgs e)
		{
			radarChart.GridType = (RadarGridType)cbxGridType.SelectedItem;
			radarChart.AreaOpacity = alpha;
			radarChart.Invalidate();
		}

		private void cbxRadarType_SelectedValueChanged(object sender, EventArgs e)
		{
			radarChart.RadarType = (RadarType)cbxRadarType.SelectedItem;
			radarChart.AreaOpacity = alpha;
			radarChart.Invalidate();
		}

		private void tbAreaOpacity_Scroll(object sender, EventArgs e)
		{
			alpha = (double)tbAreaOpacity.Value / 10.0;
			radarChart.AreaOpacity = alpha;
			radarChart.Invalidate();
		}
	}
}